@@ -160,13 +160,15 @@ class CardBase:
                                         default_if=default_if,
                                         **kwargs)
 
-    def add_row(self, *args):
+    def add_row(self, *args, extra_row_kwargs=None):
+        if extra_row_kwargs is None:
+            extra_row_kwargs = {}
         entries = []
         for arg in args:
             if isinstance(arg, str):
-                entry = self._add_entry_internal(field=arg)
+                entry = self._add_entry_internal(field=arg, **extra_row_kwargs)
             else:
-                entry = self._add_entry_internal(**arg)
+                entry = self._add_entry_internal(**arg, **extra_row_kwargs)
             if entry is not None:
                 entries.append(entry)
 
@@ -452,16 +454,18 @@ class CardBase:
                     title += letter
                 return title
 
-    def add_rows(self, *args, default='N/A', hidden=False):
+    def add_rows(self, *args, default='N/A', hidden=False, extra_row_kwargs=None):
+        if extra_row_kwargs is None:
+            extra_row_kwargs = {}
         for arg in args:
             if isinstance(arg, str):
-                self.add_entry(field=arg, default=default, hidden=hidden)
+                self.add_entry(field=arg, default=default, hidden=hidden, **extra_row_kwargs)
             elif isinstance(arg, dict):
                 if 'default' not in arg:
                     arg['default'] = default
                 if 'hidden' not in arg:
                     arg['hidden'] = hidden
-                self.add_entry(**arg)
+                self.add_entry(**arg, **extra_row_kwargs)
             elif isinstance(arg, (list, tuple)):
                 self.add_row(*arg)
 
